@@ -30,6 +30,7 @@
 #include <QMenu>
 #include <QString>
 #include <QTimer>
+#include <QPainter>
 
 #include <KAboutData>
 #include <KActionCollection>
@@ -45,10 +46,11 @@
 TopLevel::TopLevel(const KAboutData *aboutData, const QString &icon, QWidget *parent)
   : KStatusNotifierItem( parent ),
     m_popup( new KPassivePopup ),
+    m_iconName(icon),
     m_runningTeaTime( 0 ),
     m_nextNotificationTime( 0 )
 {
-    setIconByPixmap(QIcon::fromTheme(icon));
+    repaintTrayIcon(); // Set initial icon
     setCategory(ApplicationStatus);
     setStatus(Active);
     KSharedConfigPtr config = KSharedConfig::openConfig();
@@ -87,8 +89,8 @@ TopLevel::TopLevel(const KAboutData *aboutData, const QString &icon, QWidget *pa
     action->setText(i18n( "&Configure..." ) );
     connect(action, &QAction::triggered, this, &TopLevel::showSettingsDialog);
 
-    action = KStandardAction::configureNotifications(this, SLOT(configureNotifications()), m_actionCollection);
-    action = KStandardAction::quit(qApp, SLOT(quit()), m_actionCollection);
+    action = KStandardAction::configureNotifications(this, &TopLevel::configureNotifications, m_actionCollection);
+    action = KStandardAction::quit(qApp, &QCoreApplication::quit, m_actionCollection);
     action->setShortcut(0);
 
     action = m_actionCollection->addAction( QStringLiteral( "anonymous" ));
@@ -158,7 +160,8 @@ void TopLevel::setTeaList(const QList<Tea> &tealist) {
     tealistGroup.config()->sync();
 
 
-    foreach(QAction* a, m_teaActionGroup->actions() ) {
+    const auto actions = m_teaActionGroup->actions();
+    for ( QAction* a : actions ) {
         m_teaActionGroup->removeAction( a );
     }
 
@@ -237,13 +240,33 @@ void TopLevel::runTea(const Tea &tea)
 
 void TopLevel::repaintTrayIcon()
 {
-    if( m_runningTeaTime != 0 && m_usevisualize) {
-        setOverlayIconByName ( QStringLiteral("task-ongoing") );
-    }
-    else
-    {
+    QPixmap icon( KIconLoader::global()->loadIcon( m_iconName, KIconLoader::Panel ) );
+    if ( m_runningTeaTime <= 0) {
         setOverlayIconByName ( QString() );
+        setIconByPixmap( icon );
+
+        return;
     }
+
+    if ( !m_usevisualize ) {
+        setOverlayIconByName ( QStringLiteral( "task-ongoing" ) );
+        return;
+    }
+
+    QPainter painter( &icon );
+    painter.setRenderHint( QPainter::Antialiasing );
+
+    const QRectF rectangle( 1, icon.height() / 3 + 1, icon.width() / 1.5 - 2, icon.height() / 1.5 - 2 );
+
+    const int startAngle = 90 * 16;
+    const int angleSpan = -( 360*16 / m_runningTea.time() * m_runningTeaTime );
+
+    painter.setBrush( QColor( 0, 255, 0, 90 ) );
+    painter.drawPie( rectangle, startAngle, 360*16 + angleSpan );
+    painter.setBrush( QColor( 255, 0, 0, 90 ) );
+    painter.drawPie( rectangle, startAngle, angleSpan );
+
+    setIconByPixmap( icon );
 }
 
 
@@ -258,7 +281,7 @@ void TopLevel::teaTimeEvent()
 
         //NOTICE Timeout is set t ~o24 days when no auto hide is request. Ok - nearly the same...
         if( m_usepopup ) {
-            showMessage( title, content, iconName(), m_autohide ? m_autohidetime*1000 : 2100000000 );
+            showMessage( title, content, m_iconName, m_autohide ? m_autohidetime*1000 : 2100000000 );
         }
 
         KNotification::event( QStringLiteral( "ready" ), content );
@@ -279,7 +302,7 @@ void TopLevel::teaTimeEvent()
 
         if( m_runningTeaTime == m_nextNotificationTime ) {
             if( m_usepopup ) {
-                showMessage( title, content, iconName(), m_autohide ? m_autohidetime*1000 : 2100000000 );
+                showMessage( title, content, m_iconName, m_autohide ? m_autohidetime*1000 : 2100000000 );
             }
 
             KNotification::event( QLatin1String( "reminder" ), content );
@@ -354,8 +377,8 @@ void TopLevel::showPopup(bool active, const QPoint& point)
 void TopLevel::setTooltipText(const QString& content)
 {
     const QString title = i18n( "The Tea Cooker" );
-    setToolTip( iconName(), title, content );
-    m_popup->setView( title, content, KIconLoader().loadIcon(iconName(), KIconLoader::MainToolbar) );
+    setToolTip( m_iconName, title, content );
+    m_popup->setView( title, content, KIconLoader::global()->loadIcon( m_iconName, KIconLoader::MainToolbar ) );
 }
 
 
